/*
** Module   : ToggleBoxWidget.java
** Abstract : Toggle-box widget.
**
** Copyright (c) 2010-2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 SVL 20101004 Created initial version.
** 002 SIY 20110112 Suppressed warning.
** 003 SIY 20111101 Updated imports.
** 004 CA  20130930 Added LegacyResource annotation, to determine resource type.
** 005 CA  20131115 Changes related to properly instantiate dynamic resources.
** 006 EVL 20140609 Adding TOGGLE-BOX specific options handling.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Toggle-box widget.
 */
@LegacyResource(resource = LegacyResource.TOGGLE_BOX)
public class ToggleBoxWidget
extends ControlEntity
{
   /** Toggle-box-specific configuration. */
   @SuppressWarnings("unused")
   private ToggleBoxConfig tbc;

   /**
    * Default constructor.
    */
   public ToggleBoxWidget()
   {
      this(false);
   }

   /**
    * Default constructor.
    * 
    * @param    dynamic
    *           Flag indicating if this is a static or dynamic resource.
    */
   public ToggleBoxWidget(boolean dynamic)
   {
      super(dynamic, new ToggleBoxConfig(ComponentConfig.TOGGLE_BOX));
      this.tbc = (ToggleBoxConfig) config;
   }

   /**
    * Gets the CHECKED writable attribute.
    *
    * @return    The current value of the CHECKED attribute.
    */
   public boolean isChecked()
   {
      return tbc.isChecked();
   }

   /**
    * Set CHECKED attribute value.
    * 
    * @param   checked
    *          New value for the attribute.
    */
   public void setChecked(boolean checked)
   {
      tbc.setChecked(checked);
      pushScreenDefinition();
   }

   /**
    * Set CHECKED attribute value.
    * 
    * @param   checked
    *          New value for the attribute.
    */
   public void setChecked(logical checked)
   {
      setChecked(checked.booleanValue());
   }
}
